@@ -97,6 +97,10 @@ private:
     // other Qt settings
     // widget
     QString style_;
+    QColor winColor_, baseColor_, highlightColor_,
+           winTextColor_, textColor_, highlightedTextColor_,
+           linkColor_, linkVisitedColor_;
+    bool paletteChanged_;
     QString fontStr_;
     QFont font_;
     QString fixedFontStr_;
@@ -109,6 +113,8 @@ private:
     QFileSystemWatcher *settingsWatcher_;
     QString settingsFile_;
 
+    QPalette *LXQtPalette_;
+
     QStringList xdgIconThemePaths() const;
 };
 
